==> qtjambi-serialbus-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiSerialBus/QCanBusDevice_Filter_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtSerialBus/qcanbusdevice.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiSerialBus/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCanBusDevice_Filter(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCanBusDevice::Filter")
    QCanBusDevice::Filter *_ptr = reinterpret_cast<QCanBusDevice::Filter *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QCanBusDevice_Filter_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QCanBusDevice::Filter *__qt_this = new(__qtjambi_ptr) QCanBusDevice::Filter();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCanBusDevice::Filter
void __qt_destruct_QCanBusDevice_Filter(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCanBusDevice::Filter")
    reinterpret_cast<QCanBusDevice::Filter*>(ptr)->~Filter();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCanBusDevice::Filter::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_initialize_1native__Lio_qt_serialbus_QCanBusDevice_00024Filter_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanBusDevice::Filter::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCanBusDevice_Filter_0, sizeof(QCanBusDevice::Filter), typeid(QCanBusDevice::Filter), false, &deleter_QCanBusDevice_Filter, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCanBusDevice::Filter::operator==(QCanBusDevice::Filter,QCanBusDevice::Filter)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_operator_1equal_1native_1cref_1QCanBusDevice_1Filter__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID b1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBusDevice::Filter::operator==(QCanBusDevice::Filter,QCanBusDevice::Filter)", __qt_this)
        const QCanBusDevice::Filter& __qt_b1 = QtJambiAPI::valueReferenceFromNativeId<QCanBusDevice::Filter>(b1);
        __java_return_value = (*__qt_this) == __qt_b1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_setFormat_1native_1cref_1QCanBusDevice_1Filter_1FormatFilter__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint format0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QCanBusDevice::Filter::FormatFilter __qt_format0 = qtjambi_cast<QCanBusDevice::Filter::FormatFilter>(__jni_env, format0);
        __qt_this->format = QCanBusDevice::Filter::FormatFilter(__qt_format0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_format_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCanBusDevice::Filter::FormatFilter&  __qt_value = __qt_this->format;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_setFrameId_1native_1quint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint frameId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->frameId = static_cast<quint32>(frameId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_frameId_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        quint32  __qt_value = __qt_this->frameId;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_setFrameIdMask_1native_1quint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint frameIdMask0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->frameIdMask = static_cast<quint32>(frameIdMask0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_frameIdMask_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        quint32  __qt_value = __qt_this->frameIdMask;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_setType_1native_1cref_1QCanBusFrame_1FrameType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QCanBusFrame::FrameType __qt_type0 = qtjambi_cast<QCanBusFrame::FrameType>(__jni_env, type0);
        __qt_this->type = QCanBusFrame::FrameType(__qt_type0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCanBusFrame::FrameType&  __qt_value = __qt_this->type;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCanBusDevice_Filter(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCanBusDevice::Filter>("QCanBusDevice::Filter", "io/qt/serialbus/QCanBusDevice$Filter");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCanBusDevice_Filter, {
        ConstructorInfo(&__qt_construct_QCanBusDevice_Filter_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCanBusDevice_Filter);
    registerMetaType<QCanBusDevice::Filter>("QCanBusDevice::Filter");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QCanBusDevice::Filter::FormatFilter>("QCanBusDevice::Filter::FormatFilter", "io/qt/serialbus/QCanBusDevice$Filter$FormatFilter", "QCanBusDevice::Filter::FormatFilters", "QFlags<QCanBusDevice::Filter::FormatFilter>", "io/qt/serialbus/QCanBusDevice$Filter$FormatFilters");
// END: enums and flags
}

==> qtjambi-serialbus-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiSerialBus/QCanBusDevice_Filter_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtSerialBus/qcanbusdevice.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiSerialBus/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCanBusDevice_Filter(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCanBusDevice::Filter")
    QCanBusDevice::Filter *_ptr = reinterpret_cast<QCanBusDevice::Filter *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QCanBusDevice_Filter_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QCanBusDevice::Filter *__qt_this = new(__qtjambi_ptr) QCanBusDevice::Filter();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QCanBusDevice::Filter
void __qt_destruct_QCanBusDevice_Filter(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCanBusDevice::Filter")
    reinterpret_cast<QCanBusDevice::Filter*>(ptr)->~Filter();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCanBusDevice::Filter::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_initialize_1native__Lio_qt_serialbus_QCanBusDevice_00024Filter_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCanBusDevice::Filter::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCanBusDevice_Filter_0, sizeof(QCanBusDevice::Filter), typeid(QCanBusDevice::Filter), false, &deleter_QCanBusDevice_Filter, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCanBusDevice::Filter::operator==(QCanBusDevice::Filter,QCanBusDevice::Filter)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_equals_1native_1cref_1QCanBusDevice_1Filter__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID b1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCanBusDevice::Filter::operator==(QCanBusDevice::Filter,QCanBusDevice::Filter)", __qt_this)
        const QCanBusDevice::Filter& __qt_b1 = QtJambiAPI::valueReferenceFromNativeId<QCanBusDevice::Filter>(b1);
        __java_return_value = (*__qt_this) == __qt_b1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_setFormat_1native_1cref_1QCanBusDevice_1Filter_1FormatFilter__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint format0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QCanBusDevice::Filter::FormatFilter __qt_format0 = qtjambi_cast<QCanBusDevice::Filter::FormatFilter>(__jni_env, format0);
        __qt_this->format = QCanBusDevice::Filter::FormatFilter(__qt_format0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_format_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCanBusDevice::Filter::FormatFilter&  __qt_value = __qt_this->format;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_setFrameId_1native_1quint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint frameId0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->frameId = static_cast<quint32>(frameId0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_frameId_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        quint32  __qt_value = __qt_this->frameId;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_setFrameIdMask_1native_1quint32__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint frameIdMask0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->frameIdMask = static_cast<quint32>(frameIdMask0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_frameIdMask_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        quint32  __qt_value = __qt_this->frameIdMask;
        __java_return_value = jint(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_setType_1native_1cref_1QCanBusFrame_1FrameType__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint type0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QCanBusFrame::FrameType __qt_type0 = qtjambi_cast<QCanBusFrame::FrameType>(__jni_env, type0);
        __qt_this->type = QCanBusFrame::FrameType(__qt_type0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_type_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QCanBusFrame::FrameType&  __qt_value = __qt_this->type;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(hashValue);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_serialbus_QCanBusDevice_00024Filter_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCanBusDevice::Filter *__qt_this = QtJambiAPI::objectFromNativeId<QCanBusDevice::Filter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCanBusDevice_Filter(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCanBusDevice::Filter>("QCanBusDevice::Filter", "io/qt/serialbus/QCanBusDevice$Filter");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCanBusDevice_Filter, {
        ConstructorInfo(&__qt_construct_QCanBusDevice_Filter_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCanBusDevice_Filter);
    registerMetaType<QCanBusDevice::Filter>("QCanBusDevice::Filter");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QCanBusDevice::Filter::FormatFilter>("QCanBusDevice::Filter::FormatFilter", "io/qt/serialbus/QCanBusDevice$Filter$FormatFilter", "QCanBusDevice::Filter::FormatFilters", "QFlags<QCanBusDevice::Filter::FormatFilter>", "io/qt/serialbus/QCanBusDevice$Filter$FormatFilters");
// END: enums and flags
}
